@@ -28,6 +28,8 @@ int event_load(conf_t *conf, zone_t *zone)
 {
 	assert(zone);
 
+	zone_contents_t *contents = NULL;
+
 	/* Take zone file mtime and load it. */
 	time_t mtime;
 	char *filename = conf_zonefile(conf, zone->name);
@@ -39,7 +41,6 @@ int event_load(conf_t *conf, zone_t *zone)
 
 	uint32_t dnssec_refresh = time(NULL);
 
-	zone_contents_t *contents = NULL;
 	ret = zone_load_contents(conf, zone->name, &contents);
 	if (ret != KNOT_EOK) {
 		goto fail;
@@ -84,10 +85,12 @@ int event_load(conf_t *conf, zone_t *zone)
 		zone_contents_deep_free(&old);
 	}
 
-	/* Schedule notify and refresh after load. */
-	if (zone_is_slave(conf, zone)) {
+	/* Schedule refresh after load if not already scheduled. */
+	if (zone_is_slave(conf, zone) &&
+	    zone_events_get_time(zone, ZONE_EVENT_REFRESH) == 0) {
 		zone_events_schedule(zone, ZONE_EVENT_REFRESH, ZONE_EVENT_NOW);
 	}
+	/* Schedule notify. */
 	if (!zone_contents_is_empty(contents)) {
 		zone_events_schedule(zone, ZONE_EVENT_NOTIFY, ZONE_EVENT_NOW);
 		zone->bootstrap_retry = ZONE_EVENT_NOW;
