@@ -1,4 +1,4 @@
-/*  Copyright (C) 2011 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
+/*  Copyright (C) 2016 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@ typedef struct {
 	bool     dump_nsec;
 	const knot_dname_t *origin;
 	const knot_dump_style_t *style;
+	const char *first_comment;
 } dump_params_t;
 
 static int apex_node_dump_text(zone_node_t *node, dump_params_t *params)
@@ -114,6 +115,12 @@ static int node_dump_text(zone_node_t *node, void *data)
 			break;
 		}
 
+		// Dump block comment if available.
+		if (params->first_comment != NULL) {
+			fprintf(params->file, "%s", params->first_comment);
+			params->first_comment = NULL;
+		}
+
 		if (knot_rrset_txt_dump(&rrset, params->buf, params->buflen,
 		                        params->style) < 0) {
 			return KNOT_ENOMEM;
@@ -126,7 +133,7 @@ static int node_dump_text(zone_node_t *node, void *data)
 	return KNOT_EOK;
 }
 
-int zone_dump_text(zone_contents_t *zone, FILE *file)
+int zone_dump_text(zone_contents_t *zone, FILE *file, bool comments)
 {
 	if (zone == NULL || file == NULL) {
 		return KNOT_EINVAL;
@@ -138,87 +145,77 @@ int zone_dump_text(zone_contents_t *zone, FILE *file)
 		return KNOT_ENOMEM;
 	}
 
-	fprintf(file, ";; Zone dump (Knot DNS %s)\n", PACKAGE_VERSION);
+	if (comments) {
+		fprintf(file, ";; Zone dump (Knot DNS %s)\n", PACKAGE_VERSION);
+	}
 
 	// Set structure with parameters.
 	zone_node_t *apex = zone->apex;
-	dump_params_t params;
-	params.file = file;
-	params.buf = buf;
-	params.buflen = DUMP_BUF_LEN;
-	params.rr_count = 0;
-	params.origin = apex->owner;
-	params.style = &KNOT_DUMP_STYLE_DEFAULT;
+	dump_params_t params = {
+		.file = file,
+		.buf = buf,
+		.buflen = DUMP_BUF_LEN,
+		.rr_count = 0,
+		.origin = apex->owner,
+		.style = &KNOT_DUMP_STYLE_DEFAULT,
+		.dump_rrsig = false,
+		.dump_nsec = false
+	};
 
-	int ret;
+	// Dump standard zone records without RRSIGS.
+	int ret = zone_contents_tree_apply_inorder(zone, node_dump_text, &params);
+	if (ret != KNOT_EOK) {
+		return ret;
+	}
 
-	// Dump standard zone records without rrsigs.
-	params.dump_rrsig = false;
+	// Dump RRSIG records if available.
+	params.dump_rrsig = true;
 	params.dump_nsec = false;
+	params.first_comment = comments ? ";; DNSSEC signatures\n" : NULL;
 	ret = zone_contents_tree_apply_inorder(zone, node_dump_text, &params);
 	if (ret != KNOT_EOK) {
 		return ret;
 	}
 
-	// Dump DNSSEC signatures if secured.
-	if (zone_contents_is_signed(zone)) {
-		fprintf(file, ";; DNSSEC signatures\n");
-
-		// Dump rrsig records.
-		params.dump_rrsig = true;
-		params.dump_nsec = false;
-		ret = zone_contents_tree_apply_inorder(zone, node_dump_text,
-		                                       &params);
-		if (ret != KNOT_EOK) {
-			return ret;
-		}
+	// Dump NSEC chain if available.
+	params.dump_rrsig = false;
+	params.dump_nsec = true;
+	params.first_comment = comments ? ";; DNSSEC NSEC chain\n" : NULL;
+	ret = zone_contents_tree_apply_inorder(zone, node_dump_text, &params);
+	if (ret != KNOT_EOK) {
+		return ret;
 	}
 
 	// Dump NSEC3 chain if available.
-	if (knot_is_nsec3_enabled(zone)) {
-		fprintf(file, ";; DNSSEC NSEC3 chain\n");
-
-		params.dump_rrsig = false;
-		params.dump_nsec = true;
-		ret = zone_contents_nsec3_apply_inorder(zone, node_dump_text,
-		                                        &params);
-		if (ret != KNOT_EOK) {
-			return ret;
-		}
-
-		fprintf(file, ";; DNSSEC NSEC3 signatures\n");
-
-		params.dump_rrsig = true;
-		params.dump_nsec = false;
-		ret = zone_contents_nsec3_apply_inorder(zone, node_dump_text,
-		                                        &params);
-		if (ret != KNOT_EOK) {
-			return ret;
-		}
-	} else if (zone_contents_is_signed(zone)) {
-		fprintf(file, ";; DNSSEC NSEC chain\n");
-
-		// Dump nsec records.
-		params.dump_rrsig = false;
-		params.dump_nsec = true;
-		ret = zone_contents_tree_apply_inorder(zone, node_dump_text,
-		                                       &params);
-		if (ret != KNOT_EOK) {
-			return ret;
-		}
+	params.dump_rrsig = false;
+	params.dump_nsec = true;
+	params.first_comment = comments ? ";; DNSSEC NSEC3 chain\n" : NULL;
+	ret = zone_contents_nsec3_apply_inorder(zone, node_dump_text, &params);
+	if (ret != KNOT_EOK) {
+		return ret;
 	}
 
-	// Create formated date-time string.
-	time_t now = time(NULL);
-	struct tm tm;
-	localtime_r(&now, &tm);
-	char date[64];
-	strftime(date, sizeof(date), "%Y-%m-%d %H:%M:%S %Z", &tm);
+	params.dump_rrsig = true;
+	params.dump_nsec = false;
+	params.first_comment = comments ? ";; DNSSEC NSEC3 signatures\n" : NULL;
+	ret = zone_contents_nsec3_apply_inorder(zone, node_dump_text, &params);
+	if (ret != KNOT_EOK) {
+		return ret;
+	}
 
-	// Dump trailing statistics.
-	fprintf(file, ";; Written %"PRIu64" records\n"
-	              ";; Time %s\n",
-	        params.rr_count, date);
+	if (comments) {
+		// Create formatted date-time string.
+		time_t now = time(NULL);
+		struct tm tm;
+		localtime_r(&now, &tm);
+		char date[64];
+		strftime(date, sizeof(date), "%Y-%m-%d %H:%M:%S %Z", &tm);
+
+		// Dump trailing statistics.
+		fprintf(file, ";; Written %"PRIu64" records\n"
+		              ";; Time %s\n",
+	        	params.rr_count, date);
+	}
 
 	free(buf);
 
